@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: LGPL-2.1+
  */
 
-#ifndef __FWUPD_RELEASE_H
-#define __FWUPD_RELEASE_H
+#pragma once
 
 #include <glib-object.h>
 
@@ -78,6 +77,12 @@ void		 fwupd_release_set_description		(FwupdRelease	*release,
 const gchar	*fwupd_release_get_homepage		(FwupdRelease	*release);
 void		 fwupd_release_set_homepage		(FwupdRelease	*release,
 							 const gchar	*homepage);
+const gchar	*fwupd_release_get_details_url		(FwupdRelease	*release);
+void		 fwupd_release_set_details_url		(FwupdRelease	*release,
+							 const gchar	*details_url);
+const gchar	*fwupd_release_get_source_url		(FwupdRelease	*release);
+void		 fwupd_release_set_source_url		(FwupdRelease	*release,
+							 const gchar	*source_url);
 guint64		 fwupd_release_get_size			(FwupdRelease	*release);
 void		 fwupd_release_set_size			(FwupdRelease	*release,
 							 guint64	 size);
@@ -90,8 +95,8 @@ void		 fwupd_release_set_trust_flags		(FwupdRelease	*release,
 guint32		 fwupd_release_get_install_duration	(FwupdRelease	*release);
 void		 fwupd_release_set_install_duration	(FwupdRelease	*release,
 							 guint32	 duration);
+const gchar	*fwupd_release_get_update_message	(FwupdRelease	*release);
+void		 fwupd_release_set_update_message	(FwupdRelease	*release,
+							 const gchar	*update_message);
 
 G_END_DECLS
-
-#endif /* __FWUPD_RELEASE_H */
-
